package checkers.metaquals;

import java.lang.annotation.*;

// The framework can reflectively query the @TypeQualifiers, SubtypeOf, and
// QualifierRoot, then that information to construct the qualifiers hierarchy.

/**
 * An annotation that lists the type qualifiers supported by the annotated
 * {@code Checker}.
 *
 * <p>
 * Example:
 * <pre>@TypeQualifiers( { Nullable.class, NonNull.class } )
 * public class NonNullChecker extends BaseTypeChecker { ... }
 * </pre>
 */
@Documented
@Retention(RetentionPolicy.RUNTIME)
@Target ( { ElementType.TYPE } )
public @interface TypeQualifiers {
    /** The annotations supported by the annotated {@code Checker} */
    Class<? extends Annotation>[] value();
}
